# encoding: UTF-8
require 'active_record'

namespace :hacks do
  task :populate_mdb_with_mg do |t|
    Authorization.ignore_access_control(true)
    
    Member.delete_all
    Role.delete_all
    
    mg = Group.find_or_create_by_name(name: "Markedsføringsgjengen", group_type: GroupType.find_or_create_by_description(description: "Drift"))
    
    # Create all roles related to MG
    
    roles = {
      mg: Role.find_or_create_by_title( title: "mg", name: "Markedsføringsgjengen", description: "Rolle for alle medlemmer av Markedsføringsgjengen." ),
      mg_adm: Role.find_or_create_by_title( title: "mg_adm", name: "Administrasjon", description: "Rolle for alle medlemmer av Markedsføringsgjengens administrasjon." ),
      mg_gjengsjef: Role.find_or_create_by_title( title: "mg_gjengsjef", name: "Gjengsjef", description: "Rolle for sjef av Markedsføringsgjengen.", show_in_hierarchy: true ),
      mg_oko: Role.find_or_create_by_title( title: "mg_oko", name: "Økonomiansvarlig", description: "Rolle for økonomiansvarlig av Markedsføringsgjengen.", show_in_hierarchy: true ),
      mg_nestleder: Role.find_or_create_by_title( title: "mg_nestleder", name: "Nestleder", description: "Rolle for nestleder av Markedsføringsgjengen.", show_in_hierarchy: true ),
      mg_strategi: Role.find_or_create_by_title( title: "mg_strategi", name: "Strategiansvarlig", description: "Rolle for strategiansvarlig av Markedsføringsgjengen.", show_in_hierarchy: true ),
      web_sjef: Role.find_or_create_by_title( title: "mg_web_sjef", name: "Grev vev", description: "Rolle for sjef av Markedsføringsgjengens subseksjon Web.", show_in_hierarchy: true ),
      layout_sjef: Role.find_or_create_by_title( title: "mg_layout_sjef", name: "AD", description: "Rolle for sjef av Markedsføringsgjengens subseksjon Layout.", show_in_hierarchy: true ),
      marked_sjef: Role.find_or_create_by_title( title: "mg_marked_sjef", name: "Markedssjef", description: "Rolle for sjef av Markedsføringsgjengens subseksjon Marked.", show_in_hierarchy: true ),
      info_sjef: Role.find_or_create_by_title( title: "mg_info_sjef", name: "Infosjef", description: "Rolle for sjef av Markedsføringsgjengens subseksjon Info.", show_in_hierarchy: true ),
      web: Role.find_or_create_by_title( title: "mg_web", name: "Utvikler", description: "Rolle for alle medlemmer av Markedsføringsgjengens subseksjon Web.", show_in_hierarchy: true ),
      layout: Role.find_or_create_by_title( title: "mg_layout", name: "Layout", description: "Rolle for alle medlemmer av Markedsføringsgjengens subseksjon Layout.", show_in_hierarchy: true ),
      marked: Role.find_or_create_by_title( title: "mg_marked", name: "Marked", description: "Rolle for alle medlemmer av Markedsføringsgjengens subseksjon Marked.", show_in_hierarchy: true ),
      info: Role.find_or_create_by_title( title: "mg_info", name: "Info", description: "Rolle for alle medlemmer av Markedsføringsgjengens subseksjon Info.", show_in_hierarchy: true ),
    }
    
    # Connect the roles, making a hierarchy
    
    roles[:web].role = roles[:web_sjef]
    roles[:info].role = roles[:info_sjef]
    roles[:marked].role = roles[:marked_sjef]
    roles[:layout].role = roles[:layout_sjef]
    roles[:web_sjef].role = roles[:mg_gjengsjef]
    roles[:mg_adm].role = roles[:mg_gjengsjef]
    roles[:info_sjef].role = roles[:mg_gjengsjef]
    roles[:marked_sjef].role = roles[:mg_gjengsjef]
    roles[:layout_sjef].role = roles[:mg_gjengsjef]
    
    roles[:mg_oko].role = roles[:mg_adm]
    roles[:mg_nestleder].role = roles[:mg_adm]
    roles[:mg_strategi].role = roles[:mg_adm]
    
    # Connect each role to the group
    
    roles.each do |symbol, role|
      role.group = mg
      role.save!
    end
    
    # Create members
    
    members = {
      # Administrasjon
      aadne: Member.create!( fornavn: "Aadne", etternavn: "Aadland", mail: "aadne.aadland@gmail.com", passord: "passord" ),
      berge: Member.create!( fornavn: "Berge", etternavn: "Rannestad", mail: "bergerannestad@gmail.com", passord: "passord" ),
      hc: Member.create!( fornavn: "Hans Christian", etternavn: "Toftesund", mail: "toftesun@stud.ntnu.no", passord: "passord" ),
      june: Member.create!( fornavn: "June", etternavn: "Overvik", mail: "june.overvik@gmail.com", passord: "passord" ),
      # Web
      myrlund: Member.create!( fornavn: "Jonas", etternavn: "Myrlund", mail: "mg-websjef@samfundet.no", passord: "passord" ),
      amundsen: Member.create!( fornavn: "Jonas", etternavn: "Amundsen", mail: "jonasbak@gmail.com", passord: "passord" ),
      stian: Member.create!( fornavn: "Stian", etternavn: "Møllersen", mail: "mollerse@samfundet.no", passord: "passord" ),
      lorents: Member.create!( fornavn: "Lorents", etternavn: "Gravås", mail: "lorentso@stud.ntnu.no", passord: "passord" ),
      haakon: Member.create!( fornavn: "Håkon", etternavn: "Sandsmark", mail: "hsandsmark@gmail.com", passord: "passord" ),
      sv: Member.create!( fornavn: "Svein Halvor", etternavn: "Halvorsen", mail: "sveinhal@samfundet.no", passord: "passord" ),
      anders: Member.create!( fornavn: "Anders", etternavn: "Eldhuset", mail: "andereld@samfundet.no", passord: "passord" ),
      # Layout
      miriam: Member.create!( fornavn: "Miriam", etternavn: "Lillevand", mail: "miriam.lillevand@gmail.com", passord: "passord" ),
      goin: Member.create!( fornavn: "Marianne", etternavn: "Goin", mail: "marianne.goin@gmail.com", passord: "passord" ),
      mari: Member.create!( fornavn: "Mari", etternavn: "Viste", mail: "loffemari@gmail.com", passord: "passord" ),
      # Info
      eliin: Member.create!( fornavn: "Eliin", etternavn: "Hjelme", mail: "eliinsvin@gmail.com", passord: "passord" ),
      kathrine: Member.create!( fornavn: "Kathrine", etternavn: "Mikkelsen", mail: "mikkelsen.kathrine@gmail.com", passord: "passord" ),
      linda: Member.create!( fornavn: "Linda", etternavn: "Hansten", mail: "lindaplinda@gmail.com", passord: "passord" ),
      tormod: Member.create!( fornavn: "Tormod", etternavn: "Skara", mail: "tormod.skara@gmail.com", passord: "passord" ),
      vegard: Member.create!( fornavn: "Vegard", etternavn: "Schønberg ", mail: "vegardschoenberg@gmail.com", passord: "passord" ),
      # Marked
      flatoy: Member.create!( fornavn: "Vegard", etternavn: "Flatøy", mail: "vhflat@gmail.com", passord: "passord" ),
      erlend: Member.create!( fornavn: "Erlend", etternavn: "Næss", mail: "erlendnt@gmail.com", passord: "passord" ),
      paal: Member.create!( fornavn: "Pål Christian", etternavn: "Vågbø", mail: "pchrbro@gmail.com", passord: "passord" ),
      sara: Member.create!( fornavn: "Sara", etternavn: "Lindland", mail: "sara.lindland@gmail.com", passord: "passord" ),
    }
    
    # Make them member of MG
    
    members.each do |symbol, member|
      member.roles << roles[:mg]
    end
    
    # Distribute roles according to actual position in MG
    
    members[:hc].roles << roles[:mg_gjengsjef]
    members[:june].roles << roles[:mg_nestleder]
    members[:aadne].roles << roles[:mg_oko]
    members[:berge].roles << roles[:mg_strategi]
    
    members[:myrlund].roles << roles[:web_sjef]
    members[:amundsen].roles << roles[:web]
    members[:stian].roles << roles[:web]
    members[:lorents].roles << roles[:web]
    members[:haakon].roles << roles[:web]
    members[:anders].roles << roles[:web]
    members[:sv].roles << roles[:web]
    
    members[:miriam].roles << roles[:layout_sjef]
    members[:goin].roles << roles[:layout]
    members[:mari].roles << roles[:layout]
    
    members[:eliin].roles << roles[:info_sjef]
    members[:kathrine].roles << roles[:info]
    members[:linda].roles << roles[:info]
    members[:tormod].roles << roles[:info]
    members[:vegard].roles << roles[:info]
    
    members[:flatoy].roles << roles[:marked_sjef]
    members[:erlend].roles << roles[:marked]
    members[:paal].roles << roles[:marked]
    members[:sara].roles << roles[:marked]
  end
end
